package com.rf.kjb.chat.rest;

import com.rf.kjb.base.rest.BaseController;
import com.rf.kjb.chat.dao.domain.ChatAnswerEntity;
import com.rf.kjb.chat.dao.domain.ChatQuestionEntity;
import com.rf.kjb.chat.dao.domain.ResultQuestionEntity;
import com.rf.kjb.chat.service.ChatAnswerService;
import com.rf.kjb.chat.service.ChatQuestionService;
import com.rf.kjb.chat.service.ResultQuestionService;
import com.rf.kjb.exception.ErrorCode;
import com.rf.kjb.utils.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/chat")
@Api(tags = "对话")
public class ChatController extends BaseController {

    @Autowired
    private ChatQuestionService questionService;

    @Autowired
    private ChatAnswerService answerService;

    @Autowired
    private ResultQuestionService resultQuestionService;


    /**
     * 查询会话问题
     */

    @GetMapping("/getQuestion/{label}")
    @ApiOperation("查询问题信息：首次查询时，id传空字符串即可查询出第一道题目；questionType=0表示选择题，questionType=1表示填空题；当改问题的nextQuestionNo 不为空是，则表示改题为陈述，没有答案，直接在显示此问题之后再次请求该接口显示questionNo对应的题目信息即可")
    public Result getQuestion(String id , @PathVariable String label){

        if(StringUtils.isBlank(id)){
            id = "1";
        }
        ChatQuestionEntity questionEntity = this.questionService.findByIdAndLabel(id,label);
        return success(questionEntity);
    }


    @GetMapping("/getAnswer/{questionNo}/{label}")
    @ApiOperation("查询答案列表，questionNo为问题的id字段，nextQuestionNo 为此答案被选中后的下一个应该呈现的问题")
    public Result getAnswer(@PathVariable String questionNo,@PathVariable String label){
        List<ChatAnswerEntity> answerEntities = this.answerService.findByQuestionNoAndLabel(questionNo,label);
        return success(answerEntities);
    }

    @GetMapping("/getNextQuestionByScaleResult")
    @ApiOperation("根据量表测试结果查询下一问题编号")
    public Result getNextQuestionByScaleResult(String label,String result){

        ResultQuestionEntity resultQuestionEntity =  this.resultQuestionService.findByLabelAndResult(label,result);
        if (resultQuestionEntity == null){
            return fail(ErrorCode.NEXT_QUESTION_NO_NOT_FOUND);
        }
        ChatQuestionEntity byIdAndLabel = this.questionService.findByIdAndLabel(resultQuestionEntity.getNextQuestionNo(), label);
        if(byIdAndLabel == null){
            return fail(ErrorCode.NEXT_QUESTION_NO_ERROR);
        }
        return success(resultQuestionEntity);
    }

    @PostMapping("/complete/chat")
    @ApiOperation(value = "结束会话，保存会话记录",notes = "identifier:用户编号;label:只能对话分类 1-焦虑；2-抑郁；3-失眠；4-压力；chatDetail:会话详情")
    public Result completeChat(@RequestBody String json ){


        return success();
    }





}
